@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.apps import apps
 from django.core.management.base import BaseCommand
 
@@ -12,10 +9,11 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser):
         parser.add_argument(
-            '-f', '--with_fields',
+            '-f',
+            '--with_fields',
             action='store_true',
             default=False,
-            help='Show which fields is tracking for every model'
+            help='Show which fields is tracking for every model',
         )
 
     def handle(self, *args, **options):
