@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import migrations
 from django.conf import settings
 
@@ -10,7 +7,6 @@ from simple_log.fields import SimpleManyToManyField
 class Migration(migrations.Migration):
 
     dependencies = [
-        migrations.swappable_dependency(settings.SIMPLE_LOG_MODEL),
         ('simple_log', '0001_initial'),
     ]
 
