@@ -1,24 +1,13 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.template import Library
-from django.utils import six
 from django.utils.encoding import force_text
 
 
 register = Library()
 
 
-try:
-    assignment = register.assignment_tag
-except AttributeError:
-    # In django==2.0 use simple_tag
-    assignment = register.simple_tag
-
-
-@assignment()
+@register.simple_tag()
 def get_type(value):
-    if isinstance(value, six.string_types):
+    if isinstance(value, str):
         return 'str'
     if value is None:
         return 'None'
